# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.8] - 2026-02-02

### Changed
- Update to latest dependencies

### Fixed
- Limits

## [2.0.7] - 2026-01-29

### Added
- Add relation from config -> rule

### Changed
- Bump version to v2.0.7 by @github-actions[bot]

## [2.0.6] - 2026-01-29

### Changed
- Bump version to v2.0.6 by @github-actions[bot]
- Change order of base models
- Update to latest dependencies

### Fixed
- Missing fiels on GitlabRestProjectApprovalConfig

## [2.0.5] - 2026-01-28

### Changed
- Bump version to v2.0.5 by @github-actions[bot]
- Update all classes to have documentation
- Update to latest dependencies

## [2.0.4] - 2026-01-26

### Changed
- Bump version to v2.0.4 by @github-actions[bot]
- Update to latest copier version
- Update to latest copier version
- Update to latest copier version

## [2.0.3] - 2026-01-14

### Changed
- Bump version to v2.0.3 by @github-actions[bot]
- Update to v0.0.36

### Fixed
- Gitlab rest groups

## [2.0.2] - 2026-01-07

### Changed
- Bump version to v2.0.2 by @github-actions[bot]
- Rewrite modules
- More models

## [2.0.1] - 2025-10-20

### Added
- Add project and group models
- Add first models and backends

### Changed
- Bump version to v2.0.1 by @github-actions[bot]
- Initial project setup

### Fixed
- Pyproject.toml local src
- Circular import

## New Contributors
* @github-actions[bot] made their first contribution
* @ made their first contribution
[2.0.8]: https://github.com/clearskies-py/gitlab/compare/v2.0.7..v2.0.8
[2.0.7]: https://github.com/clearskies-py/gitlab/compare/v2.0.6..v2.0.7
[2.0.6]: https://github.com/clearskies-py/gitlab/compare/v2.0.5..v2.0.6
[2.0.5]: https://github.com/clearskies-py/gitlab/compare/v2.0.4..v2.0.5
[2.0.4]: https://github.com/clearskies-py/gitlab/compare/v2.0.3..v2.0.4
[2.0.3]: https://github.com/clearskies-py/gitlab/compare/v2.0.2..v2.0.3
[2.0.2]: https://github.com/clearskies-py/gitlab/compare/v2.0.1..v2.0.2

<!-- generated by git-cliff -->
